@@ -166,22 +166,40 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "INDEXED",
         "response": [
-            [1, "AC Input Voltage", "float", "V", {"icon": "power-plug"}],
-            [2, "AC Input Frequency", "float", "Hz", {"icon": "current-ac"}],
-            [3, "AC Output Voltage", "float", "V", {"icon": "power-plug"}],
-            [4, "AC Output Frequency", "float", "Hz", {"icon": "current-ac"}],
-            [5, "AC Output Apparent Power", "int", "VA", {"icon": "power-plug"}],
-            [6, "AC Output Active Power", "int", "W", {"icon": "power-plug"}],
-            [7, "AC Output Load", "int", "%", {"icon": "brightness-percent"}],
-            [8, "BUS Voltage", "int", "V", {"icon": "details"}],
-            [9, "Battery Voltage", "float", "V", {"icon": "battery-outline"}],
-            [10, "Battery Charging Current", "int", "A", {"icon": "current-dc"}],
-            [11, "Battery Capacity", "int", "%", {"icon": "battery-outline"}],
-            [12, "Inverter Heat Sink Temperature", "int", "°C", {"icon": "details"}],
-            [13, "PV1 Input Current", "float", "A", {"icon": "solar-power"}],
-            [14, "PV1 Input Voltage", "float", "V", {"icon": "solar-power"}],
-            [15, "Battery Voltage from SCC", "float", "V", {"icon": "battery-outline"}],
-            [16, "Battery Discharge Current", "int", "A", {"icon": "battery-negative"}],
+            [1, "AC Input Voltage", "float", "V", {"icon": "mdi:power-plug"}],
+            [2, "AC Input Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [3, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug"}],
+            [4, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [5, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug"}],
+            [6, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [7, "AC Output Load", "int", "%", {"icon": "mdi:brightness-percent"}],
+            [8, "BUS Voltage", "int", "V", {"icon": "mdi:details"}],
+            [9, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline"}],
+            [10, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc"}],
+            [11, "Battery Capacity", "int", "%", {"icon": "mdi:battery-outline"}],
+            [
+                12,
+                "Inverter Heat Sink Temperature",
+                "int",
+                "°C",
+                {"icon": "mdi:details"},
+            ],
+            [13, "PV1 Input Current", "float", "A", {"icon": "mdi:solar-power"}],
+            [14, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
+            [
+                15,
+                "Battery Voltage from SCC",
+                "float",
+                "V",
+                {"icon": "mdi:battery-outline"},
+            ],
+            [
+                16,
+                "Battery Discharge Current",
+                "int",
+                "A",
+                {"icon": "mdi:battery-negative"},
+            ],
             [
                 17,
                 "Device Status",
@@ -199,7 +217,7 @@ QUERY_COMMANDS = {
             ],
             [18, "Battery Voltage Offset for Fans On", "int", "10mV"],
             [19, "EEPROM Version", "int", ""],
-            [20, "PV1 Charging Power", "int", "W", {"icon": "solar-power"}],
+            [20, "PV1 Charging Power", "int", "W", {"icon": "mdi:solar-power"}],
             [
                 21,
                 "Device Status2",
@@ -227,11 +245,11 @@ QUERY_COMMANDS = {
         "name": "QPIGS2",
         "description": "General Status Parameters inquiry 2",
         "type": "QUERY",
-        "response_type": "SEQUENTIAL",
+        "response_type": "INDEXED",
         "response": [
-            ["float", "PV2 Input Current", "A"],
-            ["float", "PV2 Input Voltage", "V"],
-            ["int", "PV2 Charging Power", "W", "solar"],
+            [1, "PV2 Input Current", "float", "A", {"icon": "mdi:solar-power"}],
+            [2, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
+            [3, "PV2 Charging Power", "int", "W", {"icon": "mdi:solar-power"}],
         ],
         "test_responses": [
             b"(03.1 327.3 01026 \xc9\x8b\r",
@@ -242,12 +260,14 @@ QUERY_COMMANDS = {
         "description": "Parallel Information inquiry",
         "help": " -- example: QPGS0 queries the values of various metrics from instance 0 of parallel setup Inverters",
         "type": "QUERY",
+        "response_type": "INDEXED",
         "response": [
-            ["option", "Parallel instance number", ["Not valid", "valid"]],
-            ["string", "Serial number", ""],
+            [1, "Parallel instance number", "option", ["Not valid", "valid"]],
+            [2, "Serial number", "str", ""],
             [
-                "keyed",
+                3,
                 "Work mode",
+                "keyed",
                 {
                     "P": "Power On Mode",
                     "S": "Standby Mode",
@@ -259,8 +279,9 @@ QUERY_COMMANDS = {
                 },
             ],
             [
-                "keyed",
+                4,
                 "Fault code",
+                "keyed",
                 {
                     "00": "No fault",
                     "01": "Fan is locked",
@@ -296,24 +317,43 @@ QUERY_COMMANDS = {
                     "86": "AC output mode setting different",
                 },
             ],
-            ["float", "Grid Voltage", "V"],
-            ["float", "Grid Frequency", "Hz"],
-            ["float", "AC Output Voltage", "V"],
-            ["float", "AC Output Frequency", "Hz"],
-            ["int", "AC Output Apparent Power", "VA"],
-            ["int", "AC Output Active Power", "W"],
-            ["int", "Load Percentage", "%"],
-            ["float", "Battery Voltage", "V"],
-            ["int", "Battery Charging Current", "A"],
-            ["int", "Battery Capacity", "%"],
-            ["float", "PV1 Input Voltage", "V"],
-            ["int", "Total Charging Current", "A"],
-            ["int", "Total AC Output Apparent Power", "VA"],
-            ["int", "Total Output Active Power", "W"],
-            ["int", "Total AC Output Percentage", "%"],
+            [5, "Grid Voltage", "float", "V", {"icon": "mdi:power-plug"}],
+            [6, "Grid Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [7, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug"}],
+            [8, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [9, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug"}],
+            [10, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [11, "Load Percentage", "int", "%", {"icon": "mdi:brightness-percent"}],
+            [12, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline"}],
+            [13, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc"}],
+            [14, "Battery Capacity", "int", "%", {"icon": "mdi:battery-outline"}],
+            [15, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
             [
-                "flags",
+                16,
+                "Total Charging Current",
+                "int",
+                "A",
+                {"icon": "mdi:brightness-percent"},
+            ],
+            [
+                17,
+                "Total AC Output Apparent Power",
+                "int",
+                "VA",
+                {"icon": "mdi:power-plug"},
+            ],
+            [18, "Total Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [
+                19,
+                "Total AC Output Percentage",
+                "int",
+                "%",
+                {"icon": "mdi:brightness-percent"},
+            ],
+            [
+                20,
                 "Inverter Status",
+                "flags",
                 [
                     "Is SCC OK",
                     "Is AC Charging",
@@ -326,8 +366,9 @@ QUERY_COMMANDS = {
                 ],
             ],
             [
-                "option",
+                21,
                 "Output mode",
+                "option",
                 [
                     "single machine",
                     "parallel output",
@@ -341,19 +382,28 @@ QUERY_COMMANDS = {
                 ],
             ],
             [
-                "option",
+                22,
                 "Charger source priority",
+                "option",
                 ["Utility first", "Solar first", "Solar + Utility", "Solar only"],
             ],
-            ["int", "Max Charger Current", "A"],
-            ["int", "Max Charger Range", "A"],
-            ["int", "Max AC Charger Current", "A"],
-            ["int", "PV1 Input Current", "A"],
-            ["int", "Battery Discharge Current", "A"],
-            ["float", "PV2 Input Voltage", "V"],
-            ["int", "PV2 Input Current", "A"],
+            [23, "Max Charger Current", "int", "A"],
+            [24, "Max Charger Range", "int", "A"],
+            [25, "Max AC Charger Current", "int", "A"],
+            [26, "PV1 Input Current", "int", "A", {"icon": "mdi:solar-power"}],
+            [
+                27,
+                "Battery Discharge Current",
+                "int",
+                "A",
+                {"icon": "mdi:battery-negative"},
+            ],
+            [28, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
+            [29, "PV2 Input Current", "int", "A", {"icon": "mdi:solar-power"}],
+        ],
+        "test_responses": [
+            b"(0 92932105105315 B 00 000.0 00.00 230.0 50.00 0989 0907 012 53.2 009 090 349.8 009 00989 00907 011 10100110 0 1 100 120 030 02 000 275.3 02i]\r",
         ],
-        "test_responses": [],
         "regex": "QPGS(\\d+)$",
     },
     "QMOD": {
